==> mfc-api-model-0.1.1-sources.jar: com/valor/mfc/vms/api/model/user/UserBizDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * Created by Frank.Huang on 2016/12/10.
 */
public class UserBizDo extends AbstractPrintable {
    private long uid; //用户名
    private int bizType; //业务类型
    private long regTime;   //登记时间
    private long bizDuration; //服务时长
    private long expireTS; //失效时间
    private int bizRemaining;//业务剩余天数
    private int isBizExpire; //用户服务是否过期

    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public Long getRegTime() {
        return regTime;
    }

    public void setRegTime(Long regTime) {
        this.regTime = regTime;
    }

    public Long getBizDuration() {
        return bizDuration;
    }

    public void setBizDuration(Long bizDuration) {
        this.bizDuration = bizDuration;
    }

    public int getIsBizExpire() {
        return isBizExpire;
    }

    public void setIsBizExpire(int isBizExpire) {
        this.isBizExpire = isBizExpire;
    }

    public Long getExpireTS() {
        return expireTS;
    }

    public void setExpireTS(Long expireTS) {
        this.expireTS = expireTS;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public int getBizType() {
        return bizType;
    }

    public void setBizType(int bizType) {
        this.bizType = bizType;
    }

    public void setRegTime(long regTime) {
        this.regTime = regTime;
    }

    public void setBizDuration(long bizDuration) {
        this.bizDuration = bizDuration;
    }

    public void setExpireTS(long expireTS) {
        this.expireTS = expireTS;
    }

    public int getBizRemaining() {
        return bizRemaining;
    }

    public void setBizRemaining(int bizRemaining) {
        this.bizRemaining = bizRemaining;
    }
}

==> mfc-api-model-0.1.6-sources.jar: com/valor/mfc/vms/api/model/user/UserBizDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

/**
 * Created by Frank.Huang on 2016/12/10.
 */
public class UserBizDo extends AbstractPrintable {
    private long uid; //用户名
    private int bizType; //业务类型
    private long regTime;   //登记时间
    private long bizDuration; //服务时长
    private long expireTS; //失效时间
    private int bizRemaining;//业务剩余天数
    private int isBizExpire; //用户服务是否过期
    private long expireTimeLine;//临期时间,毫秒
    private long tipsDisplayTimeLine;// 特殊提示展示时间，毫秒
    public Long getUid() {
        return uid;
    }

    public void setUid(Long uid) {
        this.uid = uid;
    }

    public Long getRegTime() {
        return regTime;
    }

    public void setRegTime(Long regTime) {
        this.regTime = regTime;
    }

    public Long getBizDuration() {
        return bizDuration;
    }

    public void setBizDuration(Long bizDuration) {
        this.bizDuration = bizDuration;
    }

    public int getIsBizExpire() {
        return isBizExpire;
    }

    public void setIsBizExpire(int isBizExpire) {
        this.isBizExpire = isBizExpire;
    }

    public Long getExpireTS() {
        return expireTS;
    }

    public void setExpireTS(Long expireTS) {
        this.expireTS = expireTS;
    }

    public void setUid(long uid) {
        this.uid = uid;
    }

    public int getBizType() {
        return bizType;
    }

    public void setBizType(int bizType) {
        this.bizType = bizType;
    }

    public void setRegTime(long regTime) {
        this.regTime = regTime;
    }

    public void setBizDuration(long bizDuration) {
        this.bizDuration = bizDuration;
    }

    public void setExpireTS(long expireTS) {
        this.expireTS = expireTS;
    }

    public int getBizRemaining() {
        return bizRemaining;
    }

    public void setBizRemaining(int bizRemaining) {
        this.bizRemaining = bizRemaining;
    }

    public long getExpireTimeLine() {
        return expireTimeLine;
    }

    public void setExpireTimeLine(long expireTimeLine) {
        this.expireTimeLine = expireTimeLine;
    }

    public long getTipsDisplayTimeLine() {
        return tipsDisplayTimeLine;
    }

    public void setTipsDisplayTimeLine(long tipsDisplayTimeLine) {
        this.tipsDisplayTimeLine = tipsDisplayTimeLine;
    }
}
